@@ -50,10 +50,13 @@ class TypeFire:
 
     @classmethod
     def capture_fire(cls):
+        cls.PrintResult = fire.core._PrintResult
+        fire.core._PrintResult = lambda *args, **kwargs: None
         fire.core.print = lambda *args, **kwargs: None
 
     @classmethod
     def freed_fire(cls):
+        fire.core._PrintResult = cls.core._PrintResult
         fire.core.print = print 
 
     @classmethod
@@ -69,13 +72,24 @@ class TypeFire:
         return cls.agreement.clear()
 
 def likefire(obj):
+
+    @functools.wraps(obj)
+    def awrapper(command: str, *args, **kwargs):
+        try:
+            res = fire.core.Fire(obj, command)
+        except Exception as e:
+            res = None
+        async def _awrapper():
+            return res
+        return _awrapper()
+
     @functools.wraps(obj)
     def wrapper(command: str, *args, **kwargs):
         try:
             return fire.Fire(obj, command)
         except fire.core.FireExit as e:
-            return str(e)
-    return wrapper
+            return None
+    return awrapper if inspect.iscoroutinefunction(obj) else wrapper
 
 def typeswitch(obj):
 
@@ -88,6 +102,7 @@ def typeswitch(obj):
     def wrapper(*args, **kwargs):
         args, kwargs = TypeFire.switch(obj, *args, **kwargs)
         return obj(*args, **kwargs)
+
     return awrapper if inspect.iscoroutinefunction(obj) else wrapper
 
 def typefire(func):
